@@ -1,8 +1,11 @@
 package helper;
 
 use Test::More;
+use urpm::select;
+use urpm::util;
 use base 'Exporter';
-our @EXPORT = qw(need_root_and_prepare 
+our @EXPORT = qw(need_root_and_prepare need_downloader
+		 are_weak_deps_supported is_mageia
 		 start_httpd httpd_port
 		 urpmi_addmedia urpmi_removemedia urpmi_update
 		 urpm_cmd run_urpm_cmd urpmi_cmd urpmi urpmi_partial test_urpmi_fail urpme
@@ -22,14 +25,29 @@ sub need_root_and_prepare() {
     -d 'media' or die "02create_pkgs.t not done\n";
 
     system('rm -rf root');
-    isnt(-d 'root', "test root dir can not be removed $!");
-    mkdir 'root';
+    isnt(-d 'root', "test root dir can not be removed $!", "creating chroot");
+    system('mkdir -p root/etc/rpm');
+    system('echo "%_pkgverify_level none" >root/etc/rpm/macros');
     $using_root = 1;
     $ENV{LC_ALL} = 'C';
 }
 
+sub need_downloader() {
+    my @dl_helpers = qw(wget curl prozilla aria2c);
+    my $found;
+    foreach (@dl_helpers) {
+	-e "/bin/$_" and $found = 1;
+    }
+    if (!$found) {
+	warn "SKIPing because we're missing a downloader. We need one of wget/curl/prozilla/aria2c";
+	#plan skip_all => "*BSD fails those";
+	exit 0;
+    }
+}
+
+
 my $server_pid;
-sub httpd_port { 6969 }
+sub httpd_port() { 6969 }
 sub start_httpd() {
     system('perl -MNet::Server::Single -e 1') == 0 or die "module Net::Server::Single is missing (package perl-Net-Server)\n";
     $server_pid = fork();
@@ -99,7 +117,7 @@ sub urpmi_cfg() {
 sub set_urpmi_cfg_global_options {
     my ($options) = @_;
     require_ok('urpm::cfg');
-    ok(my $config = urpm::cfg::load_config(urpmi_cfg()));
+    ok(my $config = urpm::cfg::load_config(urpmi_cfg()), "loading urpmi config");
     $config->{global} = $options;
     ok(urpm::cfg::dump_config(urpmi_cfg(), $config), 'set_urpmi_cfg_global_options');
 }
@@ -125,16 +143,16 @@ sub system_should_fail {
 
 sub check_installed_fullnames {
     my (@names) = @_;
-    is(`rpm -qa --root $::pwd/root | sort`, join('', map { "$_\n" } sort(@names)));
+    is(`rpm -qa --qf '%{NVR}\\n' --root $::pwd/root | sort`, join('', map { "$_\n" } sort(@names)), 'pkgs are installed (fullnames)');
 }
 
 sub check_installed_names {
     my (@names) = @_;
-    is(`rpm -qa --qf '%{name}\\n' --root $::pwd/root | sort`, join('', map { "$_\n" } sort(@names)));
+    is(`rpm -qa --qf '%{name}\\n' --root $::pwd/root | sort`, join('', map { "$_\n" } sort(@names)), 'pkgs are installed (fullnames)');
 }
 
 sub check_nothing_installed() {
-    is(`rpm -qa --root $::pwd/root`, '');    
+    is(`rpm -qa --root $::pwd/root`, '', 'nothing is installed');
 }
 
 sub check_installed_and_remove {
@@ -158,6 +176,13 @@ sub check_installed_and_urpme {
     check_nothing_installed();
 }
 
+sub is_mageia() {
+    return -e '/etc/mageia-release';
+}
+
+sub are_weak_deps_supported() {
+    return urpm::select::_rpm_version() gt 4.12.0
+}
 
 END { 
     $using_root and system('rm -rf root');
